@@ -5,13 +5,13 @@
 #   Name:
 #       GD::Graph::axestype.pm
 #
-# $Id: axestype.pm,v 1.40 2003/06/16 02:04:12 mgjv Exp $
+# $Id: axestype.pm,v 1.42 2003/06/20 03:20:24 mgjv Exp $
 #
 #==========================================================================
 
 package GD::Graph::axestype;
 
-($GD::Graph::axestype::VERSION) = '$Revision: 1.40 $' =~ /\s([\d.]+)/;
+($GD::Graph::axestype::VERSION) = '$Revision: 1.42 $' =~ /\s([\d.]+)/;
 
 use strict;
  
@@ -1448,8 +1448,11 @@ sub _correct_y_min_max
     return ($min, $max)
 	unless $self->isa("GD::Graph::bars") or $self->isa("GD::Graph::area");
 
+    # If either $min or $max are 0, we can return
+    return ($min, $max) if $max == 0 or $min == 0;
+
     # If $min and $max on opposite end of zero axis, no work needed
-    return ($min, $max) unless ($min/$max > 0);
+    return ($min, $max) unless $min/$max > 0;
 
     if ($min > 0)
     {
